@@ -7,5 +7,5 @@ class WorldDataTimeSeries(WorldDataBase):
         return self.call_api_post("time-series", sector=sector, sub_sector=sub_sector, super_region=super_region,
                                   source=source, trend_ids=trend_ids)
     
-    def time_series_with_bucket(self, bucket, size, offset, trend_ids, **kwargs):
-        return self.call_api_post("time-series-with-bucket", bucket=bucket, size=size, offset=offset, trend_ids=trend_ids, kwargs=kwargs)
+    def time_series_with_bucket(self, bucket, trend_ids, **kwargs):
+        return self.call_api_post("time-series-with-bucket", bucket=bucket, trend_ids=trend_ids, kwargs=kwargs)
